<?php
namespace EMS\PortalFuncionario\Geral\Repository;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;

class HistoricoRepository extends Crud {

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }

    public function getMarcacoes(string $nrorg, string $nrvinculom, string $dtinicialapuracao = null, string $dtfinalapuracao = null) : array {
        try {
            if (empty($dtfinalapuracao)) {
                $dtfinalapuracao = $dtinicialapuracao;
            }

            $sql = <<<SQL
                SELECT ROWNUM,
                    NRMARCACAOPONTO,
                    MARC.NRVINCULOM,
                    VIN.NMVINCULOM,
                    TO_CHAR(NVL(DTHRAJUSTADA, DTHRMARCACAOPONTO), 'DD/MM/YYYY HH24:MI:SS') AS DTHRAJUSTADA,
                    TO_CHAR(NVL(DTHRAJUSTADA, DTHRMARCACAOPONTO), 'DD/MM/YYYY')       AS DTMARCACAOPONTO,
                    TO_CHAR(NVL(DTHRAJUSTADA, DTHRMARCACAOPONTO), 'HH24:MI')          AS HORA_MINUTO,
                    DTHRAJUSTADA                                   AS DTHRORDER,
                    IDMARCDESPREZADA,
                    IDENQUADRAHORARIO,
                    IDDIAOCORRENCIA,
                    DSJUSTIFICATIVA,
                    COL.NRCOLETOR,
                    COL.DSCOLETOR,
                    IDREFERINTERVALO,
                    (
                        CASE
                            WHEN PO_GESTOR.NRORG IS NOT NULL THEN 'S'
                            ELSE 'N'
                        END
                    ) COLETOR_GESTOR,
                    (
                        CASE
                            WHEN PO_FUNC.NRORG IS NOT NULL THEN 'S'
                            ELSE 'N'
                        END
                    ) COLETOR_FUNC
                FROM GPE_MARCACAOPONTO MARC
                JOIN GPE_COLETOR COL
                    ON COL.NRCOLETOR = MARC.NRCOLETOR
                JOIN GPE_VINCULOM VIN
                    ON VIN.NRVINCULOM                               = MARC.NRVINCULOM
                    AND VIN.NRORG                                   = MARC.NRORG
                LEFT JOIN GPE_PARAMORG PO_GESTOR
                    ON PO_GESTOR.NRCOLETORGESTOR = MARC.NRCOLETOR
                    AND PO_GESTOR.NRORG = MARC.NRORG
                LEFT JOIN GPE_PARAMORG PO_FUNC
                    ON PO_FUNC.NRCOLETORFUNCIO = MARC.NRCOLETOR
                    AND PO_FUNC.NRORG = MARC.NRORG
                WHERE MARC.NRORG                                    = :P_NRORG
                    AND MARC.NRCOLETOR                             != 21
                    AND MARC.NRCOLETOR                             != 25
                    AND MARC.NRVINCULOM                             = :P_NRVINCULOM
                    AND (TRUNC(DTHRAJUSTADA)                         BETWEEN TO_DATE(:P_DTINICIALAPURACAO,'DD/MM/YYYY') AND TO_DATE(:P_DTFINALAPURACAO,'DD/MM/YYYY') OR :P_DTINICIALAPURACAO IS NULL)
                ORDER BY DTHRORDER DESC, NRMARCACAOPONTO
SQL;
        
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"             => $nrorg,
                    "P_NRVINCULOM"        => $nrvinculom,
                    "P_DTINICIALAPURACAO" => $dtinicialapuracao,
                    "P_DTFINALAPURACAO"   => $dtfinalapuracao
                )
            );

            return $query->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }
  
}